<?php
/**
 * WHMCS Sample Payment Callback File
 *
 * This sample file demonstrates how a payment gateway callback should be
 * handled within WHMCS.
 *
 * It demonstrates verifying that the payment gateway module is active,
 * validating an Invoice ID, checking for the existence of a Transaction ID,
 * Logging the Transaction for debugging and Adding Payment to an Invoice.
 *
 * For more information, please refer to the online documentation.
 *
 * @see https://developers.whmcs.com/payment-gateways/callbacks/
 *
 * @copyright Copyright (c) WHMCS Limited 2017
 * @license http://www.whmcs.com/license/ WHMCS Eula
 */

// Require libraries needed for gateway module functions.
require_once __DIR__ . '/../../../init.php';
require_once __DIR__ . '/../../../includes/gatewayfunctions.php';
require_once __DIR__ . '/../../../includes/invoicefunctions.php';

// Detect module name from filename.
$gatewayModuleName = basename(__FILE__, '.php');

// Fetch gateway configuration parameters.
$gatewayParams = getGatewayVariables($gatewayModuleName);

// Die if module is not active.
if (!$gatewayParams['type']) {
    die("Module Not Activated");
}

// Retrieve data returned in payment gateway callback
// Varies per payment gateway

$url="https://samafricaonline.com/sam_pay/public/paymentconfirmation";

$appkey= $gatewayParams['accountID'];
$authkey= $gatewayParams['secretKey'];
$invoiceId= $_GET['whmc'];
$token= $_GET['token'];




$ch=curl_init($url);
//Setup request to send JSON via POST
$data=array('AppKey'=>$appkey,'AuthKey'=>$authkey, 'orderID'=>$invoiceId, 'token'=>$token);

$payload=json_encode($data);
//Attach encoded JSON string to the POST fields
curl_setopt($ch,CURLOPT_POSTFIELDS,$payload);
//Set the content type to application/json
curl_setopt($ch,CURLOPT_HTTPHEADER,array('Content-Type:application/json'));
//Return response instead of outputting
curl_setopt($ch,CURLOPT_RETURNTRANSFER,true);
//Execute the POST request
$result=curl_exec($ch);

//You can now complete the records on your App or Website according to the response
$apiresponse = json_decode($result);
$responsestatus = $apiresponse->status;
$responsemessage = $apiresponse->message;
//You are looking for status 200
if($responsestatus=='200'){
    $transactionId=$apiresponse->receipt;
    $paymentFee=0;
    $gatewayModuleName=$gatewayParams['paymentmethod'];
    $paymentAmount="";

     /**
     * Add Invoice Payment.
     *
     * Applies a payment transaction entry to the given invoice ID.
     *
     * @param int $invoiceId         Invoice ID
     * @param string $transactionId  Transaction ID
     * @param float $paymentAmount   Amount paid (defaults to full balance)
     * @param float $paymentFee      Payment fee (optional)
     * @param string $gatewayModule  Gateway module name
     */
    addInvoicePayment(
        $invoiceId,
        $transactionId,
        $paymentAmount,
        $paymentFee,
        $gatewayModuleName
    );
?>

<!DOCTYPE html>
<html lang="en">
<meta charset="UTF-8">
<title>Payment Successfull</title>
<meta name="viewport" content="width=device-width,initial-scale=1">
<link rel="stylesheet" href="">
<style>
</style>
<script src=""></script>
<body>



<div class="">
 <h1>Payment was successful</h1>
 <p>Transaction ID: <?=$transactionId?></p>
</div>

</body>
</html>
<?php

}
else{
?>

<!DOCTYPE html>
<html lang="en">
<meta charset="UTF-8">
<title>Payment Failed</title>
<meta name="viewport" content="width=device-width,initial-scale=1">
<link rel="stylesheet" href="">
<style>
</style>
<script src=""></script>
<body>



<div class="">
 <h1>Payment Failed</h1>
 <p><?=$responsemessage?></p>
</div>

</body>
</html>
<?php

}






//needed
// $transactionId = $_POST["x_trans_id"];
// $paymentAmount = $_POST["x_amount"];
// $paymentFee = $_POST["x_fee"];


